@@ -57,7 +57,8 @@ class SqlApiPath(ApiPath):
 
         :param filters: dictionary of filters, if not provided it will be created from
             the query_schema
-        :param query: additional query paraeters, only used when filters is not provided
+        :param query: additional query parameters, only used when filters
+            is not provided
         :param table: sqlalchemy table, if not provided the default :attr:`.db_table` is
             used instead
         """
@@ -247,4 +248,4 @@ class SqlApiPath(ApiPath):
 
         column = match.group("column")
         message = f"{column} already exists"
-        self.raiseValidationError(message=message)
+        self.raise_validation_error(message=message)
