@@ -176,3 +176,14 @@ TRUE_VALUES = frozenset(("yes", "true", "t", "1"))
 
 def str2bool(v: Union[str, bool, int]):
     return str(v).lower() in TRUE_VALUES
+
+
+class ExpectedOneOnly(RuntimeError):
+    pass
+
+
+def one_only(data: Any, *, Error: type = ExpectedOneOnly) -> Any:
+    n = len(data)
+    if not n == 1:
+        raise Error
+    return data[0]
